"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DEV = void 0;
const constants_1 = require("../../../constants");
const extrinsic_1 = require("../../../extrinsic");
const config_utils_1 = require("../../config.utils");
const moonbase_common_1 = require("../moonbase.common");
const asset = moonbase_common_1.assets[constants_1.Asset.DEV];
const astar = moonbase_common_1.chains[constants_1.Chain.AstarAlphanet];
const calamari = moonbase_common_1.chains[constants_1.Chain.CalamariAlphanet];
const karura = moonbase_common_1.chains[constants_1.Chain.KaruraAlphanet];
const calamariDevId = (0, config_utils_1.getMoonAssetId)(calamari);
const karuraDevId = (0, config_utils_1.getMoonAssetId)(karura);
exports.DEV = {
    asset,
    origin: moonbase_common_1.moonbase,
    deposit: {
        [astar.chain]: {
            origin: astar,
            balance: moonbase_common_1.balance.system(),
            extrinsicFeeBalance: moonbase_common_1.balance.system(),
            extrinsic: moonbase_common_1.extrinsic
                .polkadotXcm()
                .limitedReserveWithdrawAssets()
                .successEvent(extrinsic_1.PolkadotXcmExtrinsicSuccessEvent.Attempted)
                .origin(astar)
                .V1()
                .X2((0, config_utils_1.getPalletInstance)(astar)),
        },
        [calamari.chain]: {
            origin: calamari,
            balance: moonbase_common_1.balance.assets(calamariDevId),
            extrinsicFeeBalance: moonbase_common_1.balance.system(),
            extrinsic: moonbase_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.TransferredMultiAssets)
                .origin(calamari)
                .asset({ MantaCurrency: calamariDevId }),
        },
        [karura.chain]: {
            origin: karura,
            balance: moonbase_common_1.balance.tokens(karuraDevId),
            extrinsicFeeBalance: moonbase_common_1.balance.system(),
            extrinsic: moonbase_common_1.extrinsic
                .xTokens()
                .transfer()
                .successEvent(extrinsic_1.XTokensExtrinsicSuccessEvent.Transferred)
                .origin(karura)
                .asset({ ForeignAsset: karuraDevId }),
        },
    },
    withdraw: {
        [astar.chain]: moonbase_common_1.withdraw.xTokens({
            balance: moonbase_common_1.balance.system(),
            destination: astar,
            feePerWeight: 50000,
        }),
        [calamari.chain]: moonbase_common_1.withdraw.xTokens({
            balance: moonbase_common_1.balance.assets(calamariDevId),
            destination: calamari,
            feePerWeight: 50000,
        }),
        [karura.chain]: moonbase_common_1.withdraw.xTokens({
            balance: moonbase_common_1.balance.assets(karuraDevId),
            destination: karura,
            feePerWeight: 50000,
        }),
    },
};
//# sourceMappingURL=dev.js.map